@@ -22,7 +22,6 @@
 #include <algorithm>
 #include <tr1/array>
 
-#include <libxml++/parsers/textreader.h>
 
 #include "debug.hpp"
 #include "notebuffer.hpp"
@@ -31,6 +30,7 @@
 #include "preferences.hpp"
 #include "undo.hpp"
 
+#include "sharp/xmlreader.hpp"
 #include "sharp/xmlwriter.hpp"
 
 namespace gnote {
@@ -47,10 +47,10 @@ namespace gnote {
 
   NoteBuffer::NoteBuffer(const NoteTagTable::Ptr & tags, Note & note)
     : Gtk::TextBuffer(tags)
-    , m_undomanager(new UndoManager(Ptr(this)))
+    , m_undomanager(NULL)
     , m_note(note)
   {
-    
+    m_undomanager = new UndoManager(this);
     signal_insert().connect(sigc::mem_fun(*this, &NoteBuffer::text_insert_event));
     signal_erase().connect(sigc::mem_fun(*this, &NoteBuffer::range_deleted_event));
     signal_mark_set().connect(sigc::mem_fun(*this, &NoteBuffer::mark_set_event));
@@ -1382,7 +1382,8 @@ namespace gnote {
   {
     if(!content.empty()) {
       // it looks like an empty string does not really make the cut
-      xmlpp::TextReader xml((const unsigned char *)content.c_str(), content.size());
+      sharp::XmlReader xml;
+      xml.load_buffer(content);
       deserialize(buffer, iter, xml);
     }
   }
@@ -1399,11 +1400,12 @@ namespace gnote {
 
   void NoteBufferArchiver::deserialize(const Glib::RefPtr<Gtk::TextBuffer> & buffer, 
                                        const Gtk::TextIter & start,
-                                       xmlpp::TextReader & xml)
+                                       sharp::XmlReader & xml)
   {
     int offset = start.get_offset();
     std::stack<TagStart> tag_stack;
     TagStart tag_start;
+    Glib::ustring value;
 
     NoteTagTable::Ptr note_table = NoteTagTable::Ptr::cast_dynamic(buffer->get_tag_table());
 
@@ -1418,7 +1420,7 @@ namespace gnote {
       while (xml.read ()) {
         Gtk::TextIter insert_at;
         switch (xml.get_node_type()) {
-        case xmlpp::TextReader::Element:
+        case XML_READER_TYPE_ELEMENT:
           if (xml.get_name() == "note-content")
             break;
 
@@ -1460,13 +1462,16 @@ namespace gnote {
 
           tag_stack.push (tag_start);
           break;
-        case xmlpp::TextReader::Text:
-        case xmlpp::TextReader::Whitespace:
-        case xmlpp::TextReader::SignificantWhitespace:
+        case XML_READER_TYPE_TEXT:
+        case XML_READER_TYPE_WHITESPACE:
+        case XML_READER_TYPE_SIGNIFICANT_WHITESPACE:
           insert_at = buffer->get_iter_at_offset (offset);
-          buffer->insert (insert_at, xml.get_value());
+          value = xml.get_value();
+          buffer->insert (insert_at, value);
 
-          offset += xml.get_value().size();
+          // we need the # of chars *Unicode) and not bytes (ASCII)
+          // see bug #587070
+          offset += value.length();
 
           // If we are inside a <list-item> mark off
           // that we have encountered some content
@@ -1476,7 +1481,7 @@ namespace gnote {
           }
 
           break;
-        case xmlpp::TextReader::EndElement:
+        case XML_READER_TYPE_END_ELEMENT:
           if (xml.get_name() == "note-content")
             break;
 
