@@ -293,7 +293,7 @@ namespace gnote {
     m_on_notebook_selection_changed_cid = m_notebooksTree->get_selection()->signal_changed()
       .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_notebook_selection_changed));
     m_notebooksTree->signal_button_press_event()
-      .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_notebooks_tree_button_pressed));
+      .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_notebooks_tree_button_pressed), false);
     m_notebooksTree->signal_key_press_event()
       .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_notebooks_key_pressed));
       
@@ -330,15 +330,14 @@ namespace gnote {
     m_tree->get_selection()->signal_changed().connect(
       sigc::mem_fun(*this, &NoteRecentChanges::on_selection_changed));
     m_tree->signal_button_press_event().connect(
-      sigc::mem_fun(*this, &NoteRecentChanges::on_treeview_button_pressed));
+      sigc::mem_fun(*this, &NoteRecentChanges::on_treeview_button_pressed), false);
     m_tree->signal_motion_notify_event().connect(
-      sigc::mem_fun(*this, &NoteRecentChanges::on_treeview_motion_notify));
+      sigc::mem_fun(*this, &NoteRecentChanges::on_treeview_motion_notify), false);
     m_tree->signal_button_release_event().connect(
       sigc::mem_fun(*this, &NoteRecentChanges::on_treeview_button_released));
     m_tree->signal_drag_data_get().connect(
       sigc::mem_fun(*this, &NoteRecentChanges::on_treeview_drag_data_get));
 
-    // this cause a frakkin' warning.
     m_tree->enable_model_drag_source(m_targets,
       Gdk::BUTTON1_MASK | Gdk::BUTTON3_MASK, Gdk::ACTION_MOVE);
 
@@ -564,12 +563,7 @@ namespace gnote {
         match_count = miter->second;
         if (match_count > 0) {
           const char * fmt;
-          if(match_count == 1) {
-            fmt = _("%1% match");
-          }
-          else {
-            fmt = _("%1% matches");
-          }
+          fmt = ngettext("%1% match", "%1% matches", match_count);
           match_str = str(boost::format(fmt) % match_count);
         }
       }
@@ -581,27 +575,29 @@ namespace gnote {
 
   void NoteRecentChanges::update_total_note_count (int total)
   {
-    const char * fmt;
-    if(total == 1) {
-      fmt = _("Total: %1% note");
+    try {
+      const char * fmt;
+      fmt = ngettext("Total: %1% note", "Total: %1% notes", total);
+      m_note_count.set_text(str(boost::format (fmt) % total));
+    } 
+    catch(const std::exception & e)
+    {
+      ERR_OUT("exception: %s", e.what());
     }
-    else {
-      fmt = _("Total: %1% notes");
-    }
-    m_note_count.set_text(str(boost::format (fmt) % total));
   }
                 
   
   void NoteRecentChanges::update_match_note_count (int matches)
   {
-    const char * fmt;
-    if(matches == 1) {
-      fmt = _("Matches: %1% note");
+    try {
+      const char * fmt;
+      fmt = ngettext("Matches: %1% note", "Matches: %1% notes", matches);
+      m_note_count.set_text(str(boost::format (fmt) % matches));
     }
-    else {
-      fmt = _("Matches: %1% notes");
+    catch(const std::exception & e)
+    {
+      ERR_OUT("exception: %s", e.what());
     }
-    m_note_count.set_text(str(boost::format (fmt) % matches));
   }
                 
 
@@ -722,18 +718,14 @@ namespace gnote {
       return;
     }
                   
-    std::string uris;
+    std::vector<std::string> uris;
     for(Note::List::const_iterator iter = selected_notes.begin();
         iter != selected_notes.end(); ++iter) {
-      if (!uris.empty()) {
-        uris += "\n";
-      }
-      uris += (*iter)->uri();
+
+      uris.push_back((*iter)->uri());
     }
-                  
-    // FIXME: Gtk.SelectionData has no way to get the
-    //        requested target.
-    selection_data.set ("text/uri-list", uris.c_str());
+    
+    selection_data.set_uris(uris);
                   
     if (selected_notes.size() == 1) {
       selection_data.set_text(selected_notes.front()->get_title());
@@ -776,7 +768,10 @@ namespace gnote {
                   
     m_tree->get_path_at_pos (ev->x, ev->y,
                              dest_path, column, unused, unused);
-    if (dest_path.empty())
+    // we need to test gobj() isn't NULL.
+    // See Gtkmm bug 586437
+    // https://bugzilla.gnome.org/show_bug.cgi?id=586437
+    if (dest_path.empty() || !dest_path.gobj())
       return false;
                   
     m_clickX = ev->x;
@@ -793,7 +788,12 @@ namespace gnote {
                     
       m_tree->get_selection()->unselect_all ();
       m_tree->get_selection()->select(dest_path);
-      m_tree->row_activated(dest_path, *column);
+      // apparently Gtk::TreeView::row_activated() require a dest_path
+      // while get_path_at_pos() can return a NULL pointer.
+      // See Gtkmm bug 586438
+      // https://bugzilla.gnome.org/show_bug.cgi?id=586438
+      gtk_tree_view_row_activated(m_tree->gobj(), dest_path.gobj(), 
+                                  column?column->gobj():NULL);
       break;
     case GDK_BUTTON_PRESS:
       if (ev->button == 3) {
@@ -984,16 +984,11 @@ namespace gnote {
     return selected_notes;
   }
 
-  Note::Ptr NoteRecentChanges::get_note(const Gtk::TreeIter & iter)
-  {
-    return (*iter)[m_column_types.note];
-  }
-
   Note::Ptr NoteRecentChanges::get_note(const Gtk::TreePath & p)
   {
-    Gtk::TreeIter iter = m_store->get_iter(p); 
+    Gtk::TreeIter iter = m_store_sort->get_iter(p); 
     if(iter) {
-      return get_note(iter);
+      return (*iter)[m_column_types.note];
     }
     return Note::Ptr();
   }
@@ -1010,8 +1005,9 @@ namespace gnote {
   void NoteRecentChanges::on_delete_note()
   {
     Note::List selected_notes = get_selected_notes ();
-    if (selected_notes.size() != 1)
+    if (selected_notes.empty()) {
       return;
+    }
                   
     noteutils::show_deletion_dialog(selected_notes, this);
   }
@@ -1351,7 +1347,7 @@ namespace gnote {
   void NoteRecentChanges::on_delete_notebook()
   {
     notebooks::Notebook::Ptr notebook = get_selected_notebook ();
-    if (notebook)
+    if (!notebook)
       return;
       
     notebooks::NotebookManager::prompt_delete_notebook (this, notebook);
